# -*- coding: utf-8 -*-
"""
django-db-call

Copyright (c) 2014, Friedrich Paetzke (f.paetzke@gmail.com)
All rights reserved.

"""
from .caller import from_call, from_calls

__version__ = '0.1.1'
__author__ = 'Friedrich Paetzke'
__license__ = 'BSD'
__copyright__ = 'Copyright 2014 Friedrich Paetzke'



# -*- coding: utf-8 -*-
"""
django-db-call

Copyright (c) 2014, Friedrich Paetzke (f.paetzke@gmail.com)
All rights reserved.

"""
from setuptools import setup, find_packages


setup(name='django-db-call',
      py_modules=['django-db-call'],
      description='',
      long_description=(open('README.rst').read()),
      version='0.1.1',
      license='BSD',
      author='Friedrich Paetzke',
      author_email='f.paetzke@gmail.com',
      url='https://github.com/paetzke/django-db-call',
      packages=find_packages(exclude=['tests*']),
      install_requires=open('requirements/package.txt').read().splitlines(),
      classifiers=[
          'Framework :: Django',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: BSD License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy',
          'Topic :: Software Development :: Libraries',
          'Topic :: Utilities',
      ])



# -*- coding: utf-8 -*-
"""
django-db-call

Copyright (c) 2014, Friedrich Paetzke (f.paetzke@gmail.com)
All rights reserved.

"""
from argparse import ArgumentParser

from first import first


def _from_mysql_call(args, **kwargs):
    parser = ArgumentParser(add_help=False)
    parser.add_argument('-h', '--host', dest='host', default='')
    parser.add_argument('-u', '--user', dest='user', default='')
    parser.add_argument('-p', '--password', dest='password', default='')
    parser.add_argument('-D', dest='name', default='')
    parser.add_argument('-P', '--port', dest='port', default='')
    parser.add_argument('db_name', nargs='?', default='')

    args = parser.parse_args(args)

    db_name = first([args.name, args.db_name], default='')
    db_dict = {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': db_name,
        'USER': args.user,
        'PASSWORD': args.password,
        'HOST': args.host,
        'PORT': args.port,
    }

    if kwargs:
        db_dict['OPTIONS'] = kwargs

    return db_dict


def _from_psql_call(args, password='', **kwargs):
    parser = ArgumentParser(add_help=False)

    parser.add_argument('-d', '--dbname', dest='name', default='')
    parser.add_argument('-h', '--host', dest='host', default='')
    parser.add_argument('-p', '--port', dest='port', default='')
    parser.add_argument('-U', '--username', dest='user', default='')
    parser.add_argument('db_name', nargs='?', default='')

    args = parser.parse_args(args)

    db_name = first([args.name, args.db_name], default='')
    db_dict = {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': db_name,
        'USER': args.user,
        'PASSWORD': password,
        'HOST': args.host,
        'PORT': args.port,
    }

    if kwargs:
        db_dict['OPTIONS'] = kwargs

    return db_dict


def from_call(call, connection='default', **kwargs):
    args = call.split()

    if not args:
        raise ValueError

    if args[0] == 'mysql':
        db_dict = _from_mysql_call(args[1:], **kwargs)
    elif args[0] == 'psql':
        db_dict = _from_psql_call(args[1:], **kwargs)
    else:
        raise ValueError

    return {connection: db_dict}


def from_calls(calls):
    databases = {}

    for call in calls:
        args = []
        kwargs = {}

        for arg in call:
            if isinstance(arg, dict):
                kwargs.update(**arg)
            else:
                args.append(arg)

        database = from_call(*args, **kwargs)
        databases.update(**database)
    return databases
